from plone import api
from zope.interface import directlyProvides
from zope.schema.interfaces import IContextSourceBinder
from zope.schema.vocabulary import SimpleTerm
from zope.schema.vocabulary import SimpleVocabulary


def conference_values(context, field):
    terms = []
    nav_root = api.portal.get_navigation_root(context)
    if nav_root.portal_type != 'conference':
        return SimpleVocabulary(terms)

    for item in getattr(nav_root, field, '').split('\n'):
        terms.append(SimpleTerm(item))
    return SimpleVocabulary(terms)


def presentation_duration_types(context):
    return conference_values(context, 'presentation_duration_types')
directlyProvides(presentation_duration_types, IContextSourceBinder)


def training_class_duration_types(context):
    return conference_values(context, 'training_class_duration_types')
directlyProvides(training_class_duration_types, IContextSourceBinder)


def level_types(context):
    return conference_values(context, 'level_types')
directlyProvides(level_types, IContextSourceBinder)


def audience_types(context):
    return conference_values(context, 'audience_types')
directlyProvides(audience_types, IContextSourceBinder)


def persons(context):
    person_brains = api.content.find(
        portal_type=('person', 'keynoter'),
        context=api.portal.get_navigation_root(context),
        sort_on='sortable_title',
        sort_order='ascending')
    terms = []
    for brain in person_brains:
        token = brain.getPath()
        terms.append(SimpleTerm(
            value=brain.UID,
            token=token,
            title=brain.Title
            ))
    return SimpleVocabulary(terms)
directlyProvides(persons, IContextSourceBinder)


def form_templates(context):
    path = '/'.join(api.portal.get().getPhysicalPath())
    catalog = api.portal.get_tool('portal_catalog')
    form_brains = catalog(portal_type=('EasyForm'),
                          path={'query': path, 'depth': 1})
    terms = []
    for brain in form_brains:
        token = brain.getPath()
        terms.append(SimpleTerm(
            value=brain.UID,
            token=token,
            title=brain.Title
            ))
    return SimpleVocabulary(terms)
directlyProvides(form_templates, IContextSourceBinder)
